django-ulogin
=============


.. image:: https://travis-ci.org/marazmiki/django-ulogin.svg?branch=master
     :target: https://travis-ci.org/marazmiki/django-ulogin
     :alt: Travis CI building status

.. image:: https://coveralls.io/repos/github/marazmiki/django-ulogin/badge.svg?branch=master
     :target: https://coveralls.io/github/marazmiki/django-ulogin?branch=master
     :alt: Code coverage status

.. image:: https://badge.fury.io/py/django-ulogin.svg
     :target: http://badge.fury.io/py/django-ulogin
     :alt: PyPI release

.. image:: https://pypip.in/wheel/django-generic-helpers/badge.svg
     :target: https://pypi.python.org/pypi/django-generic-helpers/
     :alt: Wheel Status

.. image:: https://img.shields.io/pypi/pyversions/django-ulogin.svg
     :target: https://img.shields.io/pypi/pyversions/django-ulogin.svg
     :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/djversions/django-generic-helpers.svg
     :target: https://pypi.python.org/pypi/django-generic-helpers/
     :alt: Supported Django versions

.. image:: https://readthedocs.org/projects/django-ulogin/badge/?version=latest
     :target: https://django-ulogin.readthedocs.io/ru/latest/?badge=latest
     :alt: Documentation Status


Описание
--------

**django-ulogin** — подключаемое универсальное django-приложение для социальной аутентификации пользователей с помощью внешнего интернет-сервиса `uLogin <https://ulogin.ru>`_


.. attention::
    Создатели приложения никак не связаны с интернет-сервисом `uLogin <https://ulogin.ru>`_, поэтому все вопросы, касающиеся непосредственно работы сервиса, а не этого приложения, просьба отправлять на `team@ulogin.ru <team@ulogin.ru>`_.


Подробная документация проекта доступна на `Read the Docs <https://django-ulogin.readthedocs.org/>`_.
